from distutils.core import setup
from setuptools import find_packages

setup(
    name='blalacar',
    packages=find_packages(),
    version='1.1',
    description='blalacar',
    author='k.e.p',
    author_email='k.e.p@gmail.com',
    url='https://github.com/EPkravec/blalacar1',
    download_url='https://github.com/EPkravec/blalacar1/archive/1.1.tar.gz',
    keywords=['blalacar1'],
    install_requires=['simple_draw']
)